<?php

namespace App\Repositories;


use Symfony\Component\HttpKernel\Exception\HttpException;
use App\Models\ConfigPickupNode;
use Dingo\Api\Http\Response;
use Illuminate\Support\Facades\DB;
use Illuminate\Database\QueryException;

class ConfigPickupNodeRepository {
    public function __construct(ConfigPickupNode $configPickupNode) {

        $this->configPickupNode = $configPickupNode;
    }
    //列表
    public function index($request)
    {
        $where = [];
        if(isset($request['id'])){
            $where[] = ['id', '=', $request['id']];
        }

        return $this->configPickupNode->where($where)->orderBy('id', 'asc')->paginate(20);

    }

    /**
     * 添加自提点
     */
    public function create($request)
    {
        if($this->configPickupNode->where('name', trim($request['name']))->exists()){
            throw new HttpException(500, '该自提点已经存在');
        }

        $data = [
            'name' => $request['name'],
            'city_id' => $request['city_id'],
            'city_name' => $request['city_name'],
            'address' => $request['address'],
            'work_time' => $request['work_time'],
            'manager_name' => $request['manager_name']??'',
            'manager_mobile' => $request['manager_mobile'],
            'receive_type' => $request['receive_type'],
            'longitude' => $request['longitude'],
            'latitude' => $request['latitude'],
            'store_ids' => $request['store_ids'],
            'pickup_group_id' => $request['pickup_group_id'],
            'status' => 1
        ];

        if (!$this->configPickupNode->create($data)) {
            throw new HttpException(500, '添加失败');
        }
    }

    public function edit($request)
    {
        $pickupNode = $this->configPickupNode->where('id', $request['id'])->first();

        $pickupNode->name = $request['name'];
        $pickupNode->city_id = $request['city_id'];
        $pickupNode->city_name = $request['city_name'];
        $pickupNode->address = $request['address'];
        $pickupNode->work_time = $request['work_time'];
        $pickupNode->manager_name = $request['manager_name']??'';
        $pickupNode->manager_mobile = $request['manager_mobile'];
        $pickupNode->receive_type = $request['receive_type'];
        $pickupNode->longitude = $request['longitude'];
        $pickupNode->latitude = $request['latitude'];
        $pickupNode->store_ids = $request['store_ids'];
        $pickupNode->pickup_group_id = $request['pickup_group_id'];
        $pickupNode->status = 1;

        DB::beginTransaction();
        try{
            $res = $pickupNode->save();

            if($res){
                DB::commit();
                return Response::create();
            }
            DB::rollBack();
            return Response::create([
                'message'  => '编辑失败，请重试',
                'status_code'   => 500
            ]);

        }catch (QueryException $exception){
            DB::rollBack();
            return Response::create([
                'message'  => '编辑失败，请重试',
                'error' => $exception->getMessage(),
                'status_code'   => 500
            ]);
        }
    }

}